Module generator

Module generator 

This module defines the Generator struct, which is responsible for executing scripted commands

Modules

executer
This module defines error handling and the Executer trait
template
This module defines a Template struct for handling template files.

Structs

Generator
The Generator struct provides functionality to execute scripted operations, such as copying files and templates, based on the current settings.

Functions

extract_default_template
Extracts a default template to a temporary directory for use by the application.