This module defines the Generator struct, which is responsible for
executing scripted commands
Modules
- executer
- This module defines error handling and the
Executertrait - template
- This module defines a
Templatestruct for handling template files.
Structs
- Generator
- The
Generatorstruct provides functionality to execute scripted operations, such as copying files and templates, based on the current settings.
Functions
- extract_
default_ template - Extracts a default template to a temporary directory for use by the application.